#
# spec file for package python-cheroot
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-cheroot
Version:        6.5.5
Release:        3.8
Summary:        Pure-python HTTP server
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://github.com/cherrypy/cheroot
Source:         https://files.pythonhosted.org/packages/source/c/cheroot/cheroot-%{version}.tar.gz
# PATCH-FIX_UPSTREAM https://github.com/cherrypy/cheroot/pull/282
Patch1:         0001-Avoid-race-condition-on-persistent-HTTP-connections.patch
# PATCH-FIX_UPSTREAM https://github.com/cherrypy/cheroot/commit/621f4ee2c6cda819263be7b26f352abe879b3cd3
Patch2:         0002-Fix-socket.SO_PEERCRED-constant-fallback-PowerPC.patch

BuildRequires:  %{python_module more-itertools >= 2.6}
BuildRequires:  %{python_module pyOpenSSL}
BuildRequires:  %{python_module pytest >= 2.8}
BuildRequires:  %{python_module pytest-mock}
BuildRequires:  %{python_module requests-unixsocket}
BuildRequires:  %{python_module requests}
BuildRequires:  %{python_module setuptools_scm >= 1.15.0}
BuildRequires:  %{python_module setuptools_scm_git_archive >= 1.0}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module six >= 1.11.0}
BuildRequires:  %{python_module trustme}
BuildRequires:  fdupes
BuildRequires:  python-backports.functools_lru_cache
BuildRequires:  python-rpm-macros
Requires:       python-more-itertools >= 2.6
Requires:       python-six >= 1.11.0
# the package and distribution name is lowercase-cheroot,
# but PyPI claims the name is capital-Cheroot
# *smacks head against desk*
Provides:       python-Cheroot = %{version}
BuildArch:      noarch
%ifpython2
Requires:       python-backports.functools_lru_cache
%endif
%python_subpackages

%description
Cheroot is the pure-Python HTTP server used by CherryPy.

%prep
%setup -q -n cheroot-%{version}
%patch1 -p1
%patch2 -p1
# do not require cov/xdist/etc
sed -i -e '/addopts/d' pytest.ini

# drop the dependency of backports.functools_lru_cache from the python3 package
for file in "cheroot.egg-info/requires.txt" "setup.cfg"; do
    sed -i "s/backports.functools_lru_cache$/backports.functools_lru_cache ; python_version < '3.3'/" \
        "${file}"
done


%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# Exclusions because of gh#cherrypy/cheroot#200
%pytest -k 'not test_tls_client_auth'

%files %{python_files}
%license LICENSE.md
%doc README.rst CHANGES.rst
%python3_only %{_bindir}/cheroot
%{python_sitelib}/*

%changelog
* Mon May 11 2020 pablo.suarezhernandez@suse.com
- Fix Peer authentication broken on ppc64le.
- Added:
  * 0002-Fix-socket.SO_PEERCRED-constant-fallback-PowerPC.patch
* Thu May  7 2020 pablo.suarezhernandez@suse.com
- Avoid possible race condition on persistent HTTP connections (bsc#1169604)
- Added:
  * 0001-Avoid-race-condition-on-persistent-HTTP-connections.patch
* Mon Sep  2 2019 dcermak@suse.com
- Drop dependency on backports.functools_lru_cache for the python3 subpackage
  This fixes bsc#1149124
* Sun Jun  2 2019 jengelh@inai.de
- Ensure neutrality of description.
* Tue May 14 2019 mcepl@suse.com
- Update to 6.5.5 bsc#1142582:
  - Sockets now collect statistics (bytes read and written) on
    Python 3 same as Python 2.
  - Ignore OpenSSL's 1.1+ Error 0 under any Python while wrapping
    a socket.
- Switch off failing tests to avoid gh#cherrypy/cheroot#200
* Tue Mar  5 2019 tchvatal@suse.com
- Update to 6.5.4:
  * too many changes to enumerate see CHANGES.rst
- Make sure to execute testsuite
* Fri Mar 31 2017 jmatejek@suse.com
- initial commit
